CLI_CONFIG = {}
CONFIG = {}
GLOBAL = {}
SUBS = {}
DYNE = {
    "grains": ["grains"],
    "exec": ["exec"],
    "states": ["states"],
}
